@@ -1,15 +1,23 @@
-from .ninjax import run
-from .ninjax import reset
+# Context
+from .ninjax import pure
 from .ninjax import state
 from .ninjax import rng
-from .ninjax import scope
-from .ninjax import Module
-from .ninjax import Variable
-from .ninjax import cond
-from .ninjax import scan
+from .ninjax import creating
+
+# Transformations
 from .ninjax import grad
 from .ninjax import jit
 from .ninjax import pmap
+from .ninjax import cond
+from .ninjax import scan
+
+# Modules
+from .ninjax import reset
+from .ninjax import scope
+from .ninjax import Module
+from .ninjax import Variable
+
+# Integrations
 from .ninjax import HaikuModule
 from .ninjax import FlaxModule
 from .ninjax import OptaxModule
